==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2M5DnInstance.md <==
# AmazonEc2M5DnInstance


```text
aws-20210730/Resource/Compute/AmazonEc2M5DnInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')
```



| Illustration | AmazonEc2M5DnInstance | AmazonEc2M5DnInstanceCard | AmazonEc2M5DnInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstance.png) | ![illustration for AmazonEc2M5DnInstance](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstance.Local.png) | ![illustration for AmazonEc2M5DnInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstanceCard.Local.png) | ![illustration for AmazonEc2M5DnInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstanceGroup.Local.png) |




## AmazonEc2M5DnInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstance('AmazonEc2M5DnInstance', 'Amazon Ec2 M5 Dn Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstance('AmazonEc2M5DnInstance', 'Amazon Ec2 M5 Dn Instance', 'an optional tech label')
@enduml
```

## AmazonEc2M5DnInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceCard('AmazonEc2M5DnInstanceCard', 'Amazon Ec2 M5 Dn Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceCard('AmazonEc2M5DnInstanceCard', 'Amazon Ec2 M5 Dn Instance Card', 'an optional description')
@enduml
```

## AmazonEc2M5DnInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceGroup('AmazonEc2M5DnInstanceGroup', 'Amazon Ec2 M5 Dn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceGroup('AmazonEc2M5DnInstanceGroup', 'Amazon Ec2 M5 Dn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2M5DnInstance.md <==
# AmazonEc2M5DnInstance


```text
aws-20210730/Resource/Compute/AmazonEc2M5DnInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')
```



| Illustration | AmazonEc2M5DnInstance | AmazonEc2M5DnInstanceCard | AmazonEc2M5DnInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstance.png) | ![illustration for AmazonEc2M5DnInstance](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstance.Local.png) | ![illustration for AmazonEc2M5DnInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstanceCard.Local.png) | ![illustration for AmazonEc2M5DnInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2M5DnInstanceGroup.Local.png) |




## AmazonEc2M5DnInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstance('AmazonEc2M5DnInstance', 'Amazon Ec2 M5 Dn Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstance('AmazonEc2M5DnInstance', 'Amazon Ec2 M5 Dn Instance', 'an optional tech label')
@enduml
```

## AmazonEc2M5DnInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceCard('AmazonEc2M5DnInstanceCard', 'Amazon Ec2 M5 Dn Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceCard('AmazonEc2M5DnInstanceCard', 'Amazon Ec2 M5 Dn Instance Card', 'an optional description')
@enduml
```

## AmazonEc2M5DnInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceGroup('AmazonEc2M5DnInstanceGroup', 'Amazon Ec2 M5 Dn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5DnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5DnInstance')

' renders the element
AmazonEc2M5DnInstanceGroup('AmazonEc2M5DnInstanceGroup', 'Amazon Ec2 M5 Dn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
